package org.ssssssss.magicboot.utils;

import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;

import java.util.concurrent.TimeUnit;

public class CaffeineCacheUtil {

    private static final Cache<Object, Object> cache = Caffeine.newBuilder()
            .maximumSize(100) // 最大缓存容量
            .expireAfterWrite(120, TimeUnit.MINUTES) // 120分钟后过期
            .build();

    /**
     * 存储数据到缓存
     *
     * @param key   缓存的键
     * @param value 缓存的值
     */
    public static void put(Object key, Object value) {
        cache.put(key, value);
    }

    /**
     * 从缓存中获取数据
     *
     * @param key 缓存的键
     * @return 缓存的值，如果不存在则返回null
     */
    public static Object get(Object key) {
        return cache.getIfPresent(key);
    }

    /**
     * 从缓存中删除数据
     *
     * @param key 缓存的键
     */
    public static void remove(Object key) {
        cache.invalidate(key);
    }

    public static void main(String[] args) {
        // 存储数据到缓存
        put("key1", "value1");

        // 从缓存中获取数据
        Object value = get("key1");
        System.out.println("Cached value for key1: " + value);

        // 从缓存中删除数据
        remove("key1");

        // 尝试获取被删除的数据
        value = get("key1");
        System.out.println("Cached value for key1 after removal: " + value);
    }
}
